/** Framework Resposável pelo Banckend */
let express = require('express')

/** Módulo responsável pela atualização dos objetos dos pedidos*/
let updater = require('./modules/updater')

/** Responsável por publicar para a API no endpoint especificado no environment as devidas modificações */
let publisher = require('./services/publisher')()

/** Fila de ações a serem enviadas ao endpoint */
let queue = require('./modules/queue')

process.database = require('./services/database')

/** Carrega as configurações de ambiente */
let environment = require('./modules/environment')
const { config } = require('process')

/** Instância da aplicação BACKEND */
let app = express()
let port = environment.webserver.port

/** Servidor HTTP do Node */
let server = require('http').createServer(app)

/** socket.io */
let io = require('socket.io')(server)

updater.setSocket(io)

/** Traduzir as requisições para JSON */
app.use(require('body-parser').json())

/** Define a pasta mobile como estática disponível em / */
app.use(express.static(environment.theme.current))

io.on('connect', function(socket){
	socket.on('giveMeAll', (data)=>{
		socket.emit('takeItAll', true);
		socket.emit('done', updater.getCurrentObjectDone())
		socket.emit('doing', updater.getCurrentObjectDoing())
		socket.emit('setTitle', environment.title.description)
		socket.emit('setPrefix', environment.prefix.value)
		socket.emit('setPrimaryColor', environment.color.primary)
	})
})


/** Rota de apresentação da API */
app.get('/api/v1/', function(req, res){
	mensagem = `
		<style>
		.msg_center {
			width: 100%;
			height: 100%;
			display: flex;
			justify-content: center;
			align-items: center;
			font-size: 2.5vw;
		}
		</style>
		<div class="msg_center">
			<pre>PSD - Api v1.0.0</pre>
		</div>
	`
	res.send(mensagem)
})

/** Rota de autenticação */
app.post('/api/v1/auth',(req,res) => {
	msg = req.body
	res.send( msg )
})

app.get('/identification/', (req, res) => {
	res.send(environment.identification);
})

app.post('/receive/', (req, res) => {
	res.send('ok')
})

/** run panelcore */
panelcore = require('./services/panelcore')(io)

/** Subir o servidor na porta setada */
server.listen(port, function(){
	console.log(`This server is running on ${port}`)
})